@@ -6,23 +6,37 @@ use 5.010;
 use Moo 'with';
 use Scalar::Util 'blessed';
 use Types::Standard 'Any';
-use Data::Object 'deduce';
+use Data::Object 'deduce_deep', 'detract_deep';
 
 with 'Data::Object::Role::Universal';
+with 'Data::Object::Role::Detract';
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 sub new {
     my $class = shift;
     my $data  = shift;
 
     $class = ref($class) || $class;
-    $data  = Any->($data)
-        unless blessed($data) && $data->isa($class);
+    unless (blessed($data) && $data->isa($class)) {
+        $data = Any->($data);
+    }
+
+    if (blessed($data) && $data->isa('Regexp') && $^V <= v5.12.0) {
+        $data = do {\(my $q = qr/$data/)};
+    }
 
     return bless ref($data) ? $data : \$data, $class;
 }
 
+sub data {
+    goto &detract;
+}
+
+sub detract {
+    return detract_deep shift;
+}
+
 1;
 
 __END__
@@ -37,7 +51,7 @@ Data::Object::Universal - A Universal Object for Perl 5
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
